@@ -118,7 +118,7 @@ impl PlusMinusHeaderHighlighter {
         }
 
         let (mut old_tokens, mut new_tokens, _, _) =
-            to_highlighted_tokens(&self.old_name, &self.new_name);
+            to_highlighted_tokens(&self.old_name, &self.new_name, false);
 
         lowlight_timestamp(&mut old_tokens);
         lowlight_timestamp(&mut new_tokens);
