@@ -9,10 +9,11 @@ use crate::ansi::ANSI_STYLE_NORMAL;
 
 #[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub(crate) enum Style {
+    Lowlighted,
+    Context,
     Plain,
     Highlighted,
     Error,
-    Lowlighted,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -200,6 +201,16 @@ fn render_row(line_style: &LineStyle, prefix: &str, row: &[StyledToken]) -> Stri
     // Render tokens
     for token in row {
         let new_style = match token.style {
+            Style::Context => AnsiStyle {
+                inverse: false,
+                weight: Weight::Normal,
+                color: Default,
+            },
+            Style::Lowlighted => AnsiStyle {
+                inverse: false,
+                weight: Weight::Faint,
+                color: Default,
+            },
             Style::Plain => line_style.plain_style,
             Style::Highlighted => line_style.highlighted_style,
             Style::Error => AnsiStyle {
@@ -207,11 +218,6 @@ fn render_row(line_style: &LineStyle, prefix: &str, row: &[StyledToken]) -> Stri
                 weight: Weight::Normal,
                 color: Red,
             },
-            Style::Lowlighted => AnsiStyle {
-                inverse: false,
-                weight: Weight::Faint,
-                color: Default,
-            },
         };
 
         rendered.push_str(&new_style.from(&current_style));
@@ -365,6 +371,42 @@ pub(crate) fn align_tabs(old: &mut [StyledToken], new: &mut [StyledToken]) {
     new[new_tab_index_token].token = new_spaces;
 }
 
+/// If a line contains only plain tokens, style all tokens on that line as
+/// context. Lines are separated by newline tokens.
+///
+/// This can happen during conflicts highlighting.
+pub fn contextualize_unhighlighted_lines(tokens: &mut [StyledToken]) {
+    let mut line_start = 0;
+    for i in 0..tokens.len() {
+        if tokens[i].token != "\n" {
+            continue;
+        }
+
+        // Line ended
+
+        if tokens[line_start..(i + 1)]
+            .iter()
+            .all(|token| token.style == Style::Plain)
+        {
+            // Line contains only plain tokens
+            for token in &mut tokens[line_start..i] {
+                token.style = Style::Context;
+            }
+        }
+        line_start = i + 1;
+    }
+
+    // Handle the last line
+    if tokens[line_start..]
+        .iter()
+        .all(|token| token.style == Style::Plain)
+    {
+        for token in &mut tokens[line_start..] {
+            token.style = Style::Context;
+        }
+    }
+}
+
 /// Highlight single space between two highlighted tokens
 pub fn bridge_consecutive_highlighted_tokens(tokens: &mut [StyledToken]) {
     enum FoundState {
